@@ -6,7 +6,7 @@ import os
 class Hive(DataStorage):
 
     # overriding abstract method
-    def load_dataset(self, spark, read_all=True, input_dest='', header=True):
+    def load_dataset(self, read_all=True, input_dest='', header=True):
 
         input_columns = self.args["input-columns"] if "input-columns" in self.args else "*"
 
@@ -24,9 +24,9 @@ class Hive(DataStorage):
             input_columns = ','.join(columns_list)
 
         if read_all:
-            df = spark.sql("SELECT * FROM " + input_dataset)
+            df = self.spark.sql("SELECT * FROM " + input_dataset)
         else:
-            df = spark.sql("SELECT " + input_columns + " FROM " + input_dataset)
+            df = self.spark.sql("SELECT " + input_columns + " FROM " + input_dataset)
 
         # rename column
         for column in input_columns.split(","):
@@ -43,4 +43,6 @@ class Hive(DataStorage):
 
         os.environ["HADOOP_USER_NAME"] = self.args["hiveHadoopUserName-output-dataset"]
 
+        database_name = output_dataset.split(".")[0]
+        self.spark.sql("CREATE DATABASE IF NOT EXISTS " + database_name)
         df.write.mode("overwrite").saveAsTable(output_dataset)
